@@ -1,7 +1,7 @@
 # coding: utf-8
 
 from django.db.models import BooleanField, PositiveIntegerField, \
-                              CharField
+                             CharField
 
 from cms.models import CMSPlugin
 from filer.fields.folder import FilerFolderField
@@ -72,8 +72,14 @@ class SliderPlugin(CMSPlugin):
     @property
     def images(self):
         if not hasattr(self, '__images'):
-            self.__images = filter(lambda f: f.file_type == 'Image',
-                                   self.album.files)
+            files = self.album.files
+            self.__images = [f for f in files if f.file_type == 'Image']
+            self.__images.sort()
         return self.__images
 
+    @property
+    def size(self):
+        if self.width and self.height:
+            return self.width, self.height
+
     search_fields = ('title', 'album__title',)
